rmdx_paper: Rmdx journal document (paper) format

Description Usage Arguments Details Value Examples

View source: R/rmdx_paper.R

Description

\lifecycle

experimental

Usage

1

Arguments

...

arguments to be passed to pdf_document

Details

This format is highly based in arxiv_article. The main changes can be summarized as:

  1. An alternative abstract (abstract_alt) is included with its respective title (aatitle). Which can be used to write the abstract in another language.

  2. A short title (short-title) is included and placed at the top of the document pages.

  3. Add a language (lang) argument for locale configurations. See Latex international language support for details.

Value

An R Markdown output format object to be passed to render

Examples

1
2
3
4
5
6
7
## Not run: 
---
...
output: Rmdx::rmdx_paper
---

## End(Not run)

drdsdaniel/Rmdx documentation built on Nov. 8, 2021, 2:39 a.m.