Description Usage Arguments Details Value Examples
experimental
1 |
... |
arguments to be passed to |
This format is highly based in arxiv_article.
The main changes can be summarized as:
An alternative abstract (abstract_alt) is included with its respective
title (aatitle). Which can be used to write the abstract in another
language.
A short title (short-title) is included and placed at the top of
the document pages.
Add a language (lang) argument for locale configurations. See
Latex international language support for details.
An R Markdown output format object to be passed to render
1 2 3 4 5 6 7 | ## Not run:
---
...
output: Rmdx::rmdx_paper
---
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.